@@ -5,27 +5,33 @@
  */
 
 #include "conferencecontroller.h"
-#include "settingscontroller.h"
 #include "conference.h"
+#include "settingscontroller.h"
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <QDebug>
 #include <QDir>
-#include <QJsonDocument>
 #include <QJsonArray>
-#include <QNetworkRequest>
+#include <QJsonDocument>
 #include <QNetworkReply>
-#include <KSharedConfig>
-#include <KConfigGroup>
+#include <QNetworkRequest>
+
+using namespace Qt::Literals::StringLiterals;
 
 class ConferenceController::Private
 {
 public:
-    Private() : config {"kongressrc"}
-    {};
+    Private()
+        : config{u"kongressrc"_s} {};
     KConfig config;
     QNetworkAccessManager *nam = nullptr;
 };
 
-ConferenceController::ConferenceController(QObject *parent) : QObject {parent}, m_active_conference {nullptr}, m_conferences_file {new QFile {}}, d {new Private}
+ConferenceController::ConferenceController(QObject *parent)
+    : QObject{parent}
+    , m_active_conference{nullptr}
+    , m_conferences_file{new QFile{}}
+    , d{new Private}
 {
     connect(this, &ConferenceController::conferencesLoaded, [this]() {
         activateDefaultConference();
@@ -57,11 +63,11 @@ void ConferenceController::loadConferences()
     const auto dir = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     QDir().mkpath(dir);
 
-    QLatin1String fileName {"/conference-data.json"};
-    m_conferences_file = new QFile {dir + fileName};
+    QLatin1String fileName{"/conference-data.json"};
+    m_conferences_file = new QFile{dir + fileName};
 
-    const QUrl conferencesUrl {QStringLiteral("https://autoconfig.kde.org/kongress") + fileName};
-    QNetworkRequest request {conferencesUrl};
+    const QUrl conferencesUrl{QStringLiteral("https://autoconfig.kde.org/kongress") + fileName};
+    QNetworkRequest request{conferencesUrl};
     auto reply = d->nam->get(request);
 
     connect(reply, &QNetworkReply::finished, [this, reply]() {
@@ -85,14 +91,14 @@ void ConferenceController::loadConferencesFromFile(QFile &jsonFile)
         return;
     }
 
-    QString data;
+    QByteArray data;
 
     if (jsonFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
         data = jsonFile.readAll();
         jsonFile.close();
     }
 
-    auto jsonDoc = QJsonDocument::fromJson(data.toUtf8());
+    auto jsonDoc = QJsonDocument::fromJson(data);
     QVariantList jsonVarList;
 
     if (!jsonDoc.isEmpty() && jsonDoc.isArray()) {
@@ -109,7 +115,7 @@ void ConferenceController::loadConferencesFromFile(QFile &jsonFile)
 
 void ConferenceController::loadConference(const QJsonObject &jsonObj)
 {
-    auto conferenceId = jsonObj["id"].toString();
+    auto conferenceId = jsonObj["id"_L1].toString();
 
     for (const auto cf : std::as_const(m_conferences)) {
         if (cf->id() == conferenceId) {
@@ -118,18 +124,18 @@ void ConferenceController::loadConference(const QJsonObject &jsonObj)
         }
     }
 
-    auto conference = new Conference {this};
+    auto conference = new Conference{this};
     conference->setId(conferenceId);
-    conference->setName(jsonObj["name"].toString());
-    conference->setDescription(jsonObj["description"].toString());
-    conference->setIcalUrl(jsonObj["icalUrl"].toString());
-    auto jsonDays = jsonObj["days"].toVariant();
+    conference->setName(jsonObj["name"_L1].toString());
+    conference->setDescription(jsonObj["description"_L1].toString());
+    conference->setIcalUrl(jsonObj["icalUrl"_L1].toString());
+    auto jsonDays = jsonObj["days"_L1].toVariant();
     conference->setDays(jsonDays.toStringList());
-    conference->setVenueImageUrl(jsonObj["venueImageUrl"].toString());
-    conference->setVenueLatitude(jsonObj["venueLatitude"].toString());
-    conference->setVenueLongitude(jsonObj["venueLongitude"].toString());
-    conference->setVenueOsmUrl(jsonObj["venueOsmUrl"].toString());
-    conference->setTimeZoneId(jsonObj["timeZoneId"].toString());
+    conference->setVenueImageUrl(jsonObj["venueImageUrl"_L1].toString());
+    conference->setVenueLatitude(jsonObj["venueLatitude"_L1].toString());
+    conference->setVenueLongitude(jsonObj["venueLongitude"_L1].toString());
+    conference->setVenueOsmUrl(jsonObj["venueOsmUrl"_L1].toString());
+    conference->setTimeZoneId(jsonObj["timeZoneId"_L1].toString());
 
     m_conferences << conference;
 }
@@ -147,7 +153,6 @@ void ConferenceController::activateConference(const QString &conferenceId)
 
     for (const auto cf : std::as_const(m_conferences)) {
         if (cf->id() == conferenceId) {
-
             m_active_conference = cf;
             qDebug() << "activateConference: conference " << conferenceId << " activated";
 
@@ -167,7 +172,7 @@ void ConferenceController::activateDefaultConference()
 
 QString ConferenceController::defaultConferenceId() const
 {
-    auto confId = d->config.group("general").readEntry("defaultConferenceId", QString {});
+    auto confId = d->config.group(u"general"_s).readEntry("defaultConferenceId", QString{});
     d->config.sync();
 
     return confId;
@@ -175,7 +180,7 @@ QString ConferenceController::defaultConferenceId() const
 
 void ConferenceController::setDefaultConferenceId(const QString &confId)
 {
-    d->config.group("general").writeEntry("defaultConferenceId", confId);
+    d->config.group(u"general"_s).writeEntry("defaultConferenceId", confId);
     d->config.sync();
 
     Q_EMIT defaultConferenceIdChanged();
@@ -184,7 +189,7 @@ void ConferenceController::setDefaultConferenceId(const QString &confId)
 void ConferenceController::clearActiveConference()
 {
     m_active_conference = nullptr;
-    setDefaultConferenceId(QString {});
+    setDefaultConferenceId(QString{});
     Q_EMIT activeConferenceChanged();
 }
 
