@@ -12,36 +12,35 @@
 #include <QApplication>
 #endif
 
+#include "calendarcontroller.h"
+#include "conference.h"
+#include "conferencecontroller.h"
+#include "conferencemodel.h"
+#include "eventcontroller.h"
+#include "eventmodel.h"
+#include "localcalendar.h"
+#include "settingscontroller.h"
+#include "version.h"
+#include <KAboutData>
+#include <KLocalizedContext>
+#include <KLocalizedString>
+#include <QCommandLineParser>
+#include <QIcon>
 #include <QNetworkAccessManager>
 #include <QNetworkDiskCache>
 #include <QQmlApplicationEngine>
-#include <QUrl>
-#include <QQuickStyle>
-#include <QCommandLineParser>
 #include <QQmlContext>
-#include <QIcon>
+#include <QQuickStyle>
 #include <QStandardPaths>
-#include <KLocalizedContext>
-#include <KLocalizedString>
-#include <KAboutData>
-#include "calendarcontroller.h"
-#include "localcalendar.h"
-#include "eventmodel.h"
-#include "eventcontroller.h"
-#include "conferencemodel.h"
-#include "conferencecontroller.h"
-#include "settingscontroller.h"
-#include "calendarcontroller.h"
-#include "conference.h"
-#include "version.h"
+#include <QUrl>
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
-    QGuiApplication app {argc, argv};
+    QGuiApplication app{argc, argv};
     QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
-    QApplication app {argc, argv};
+    QApplication app{argc, argv};
     // Default to org.kde.desktop style unless the user forces another style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
@@ -49,9 +48,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif
     KLocalizedString::setApplicationDomain("kongress");
 
-    KAboutData about {QStringLiteral("kongress"), i18n("Kongress"), QStringLiteral(KONGRESS_VERSION_STRING), i18n("KDE Conference Companion"), KAboutLicense::GPL_V3, i18n("© 2021 KDE Community")};
-    about.setOrganizationDomain(QByteArray {"kde.org"});
-    about.setProductName(QByteArray {"kongress"});
+    KAboutData about{QStringLiteral("kongress"),
+                     i18n("Kongress"),
+                     QStringLiteral(KONGRESS_VERSION_STRING),
+                     i18n("KDE Conference Companion"),
+                     KAboutLicense::GPL_V3,
+                     i18n("© 2021 KDE Community")};
+    about.setOrganizationDomain(QByteArray{"kde.org"});
+    about.setProductName(QByteArray{"kongress"});
     about.addAuthor(i18nc("@info:credit", "Dimitris Kardarakos"), i18nc("@info:credit", "Maintainer and Developer"), QStringLiteral("dimkard@posteo.net"));
     about.setHomepage(QStringLiteral("https://invent.kde.org/utilities/kongress"));
 
@@ -62,10 +66,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.process(app);
     about.processCommandLine(&parser);
 
-    QGuiApplication::setApplicationName(about.componentName());
-    QGuiApplication::setApplicationDisplayName(about.displayName());
-    QGuiApplication::setOrganizationDomain(about.organizationDomain());
-    QGuiApplication::setApplicationVersion(about.version());
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kongress")));
 
     QNetworkAccessManager nam;
@@ -97,9 +97,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonInstance<EventController>("org.kde.kongress", 0, 1, "EventController", &eventController);
 
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextObject(new KLocalizedContext {&engine});
+    engine.rootContext()->setContextObject(new KLocalizedContext{&engine});
     engine.rootContext()->setContextProperty(QStringLiteral("_about"), QVariant::fromValue(about));
-    engine.load(QUrl {QStringLiteral("qrc:///Main.qml")});
+    engine.loadFromModule("org.kde.kongress", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
